@@ -1,24 +1,12 @@
-/* Copyright (C) 2017-2022 Greenbone AG
+/* SPDX-FileCopyrightText: 2024 Greenbone AG
  *
  * SPDX-License-Identifier: AGPL-3.0-or-later
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Affero General Public License
- * as published by the Free Software Foundation, either version 3
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
-import logger from 'gmp/log';
 
 import registerCommand from 'gmp/command';
-
+import EntitiesCommand from 'gmp/commands/entities';
+import EntityCommand from 'gmp/commands/entity';
+import logger from 'gmp/log';
 import Note from 'gmp/models/note';
 import {
   DEFAULT_DAYS,
@@ -27,9 +15,6 @@ import {
   MANUAL,
 } from 'gmp/models/override';
 
-import EntitiesCommand from './entities';
-import EntityCommand from './entity';
-
 const log = logger.getLogger('gmp.commands.notes');
 
 class NoteCommand extends EntityCommand {
@@ -128,5 +113,3 @@ class NotesCommand extends EntitiesCommand {
 
 registerCommand('note', NoteCommand);
 registerCommand('notes', NotesCommand);
-
-// vim: set ts=2 sw=2 tw=80:
