@@ -1,29 +1,15 @@
-/* Copyright (C) 2018-2022 Greenbone AG
+/* SPDX-FileCopyrightText: 2024 Greenbone AG
  *
  * SPDX-License-Identifier: AGPL-3.0-or-later
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Affero General Public License
- * as published by the Free Software Foundation, either version 3
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
-import {isFunction} from 'gmp/utils/identity';
-import {pluralizeType} from 'gmp/utils/entitytype';
 
+import {describe, test, expect, testing} from '@gsa/testing';
 import Filter from 'gmp/models/filter';
-
+import {pluralizeType} from 'gmp/utils/entitytype';
+import {isFunction} from 'gmp/utils/identity';
+import {types} from 'web/store/entities/utils/actions';
 import {filterIdentifier} from 'web/store/utils';
 
-import {types} from './actions';
-
 export const createRootState = stateData => ({
   entities: {
     ...stateData,
@@ -226,11 +212,11 @@ export const testLoadEntities = (entityType, loadEntities) => {
           [filterIdentifier(filter)]: false,
         },
       });
-      const getState = jest.fn().mockReturnValue(rootState);
+      const getState = testing.fn().mockReturnValue(rootState);
 
-      const dispatch = jest.fn();
+      const dispatch = testing.fn();
 
-      const get = jest.fn().mockReturnValue(
+      const get = testing.fn().mockReturnValue(
         Promise.resolve({
           data: 'foo',
           meta: {
@@ -281,11 +267,11 @@ export const testLoadEntities = (entityType, loadEntities) => {
         },
       });
 
-      const getState = jest.fn().mockReturnValue(rootState);
+      const getState = testing.fn().mockReturnValue(rootState);
 
-      const dispatch = jest.fn();
+      const dispatch = testing.fn();
 
-      const get = jest.fn().mockReturnValue(Promise.resolve([{id: 'foo'}]));
+      const get = testing.fn().mockReturnValue(Promise.resolve([{id: 'foo'}]));
 
       const gmp = {
         [pluralizeType(entityType)]: {
@@ -308,11 +294,11 @@ export const testLoadEntities = (entityType, loadEntities) => {
         },
       });
 
-      const getState = jest.fn().mockReturnValue(rootState);
+      const getState = testing.fn().mockReturnValue(rootState);
 
-      const dispatch = jest.fn();
+      const dispatch = testing.fn();
 
-      const get = jest.fn().mockReturnValue(Promise.reject('AnError'));
+      const get = testing.fn().mockReturnValue(Promise.reject('AnError'));
 
       const gmp = {
         [pluralizeType(entityType)]: {
@@ -456,11 +442,11 @@ export const testLoadEntity = (entityType, loadEntity) => {
           [id]: false,
         },
       });
-      const getState = jest.fn().mockReturnValue(rootState);
+      const getState = testing.fn().mockReturnValue(rootState);
 
-      const dispatch = jest.fn();
+      const dispatch = testing.fn();
 
-      const get = jest.fn().mockReturnValue(
+      const get = testing.fn().mockReturnValue(
         Promise.resolve({
           data: {foo: 'bar'},
         }),
@@ -505,11 +491,11 @@ export const testLoadEntity = (entityType, loadEntity) => {
         },
       });
 
-      const getState = jest.fn().mockReturnValue(rootState);
+      const getState = testing.fn().mockReturnValue(rootState);
 
-      const dispatch = jest.fn();
+      const dispatch = testing.fn();
 
-      const get = jest.fn().mockReturnValue(Promise.resolve([{id: 'foo'}]));
+      const get = testing.fn().mockReturnValue(Promise.resolve([{id: 'foo'}]));
 
       const gmp = {
         [entityType]: {
@@ -532,11 +518,11 @@ export const testLoadEntity = (entityType, loadEntity) => {
         },
       });
 
-      const getState = jest.fn().mockReturnValue(rootState);
+      const getState = testing.fn().mockReturnValue(rootState);
 
-      const dispatch = jest.fn();
+      const dispatch = testing.fn();
 
-      const get = jest.fn().mockReturnValue(Promise.reject('An Error'));
+      const get = testing.fn().mockReturnValue(Promise.reject('An Error'));
 
       const gmp = {
         [entityType]: {
@@ -585,5 +571,3 @@ export const testAll = (
   testReducerForEntities(name, reducer, entitiesLoadingActions);
   testReducerForEntity(name, reducer, entityLoadingActions);
 };
-
-// vim: set ts=2 sw=2 tw=80:
